@@ -486,8 +486,7 @@ class Tensor(torch.Tensor):
         if device is not None: to_device = device
         if to_device is not None and to_device != data.device: data = data.to(to_device)
         self = torch.Tensor._make_subclass(cls, data, requires_grad)
-        if isinstance(data, cls):
-            self.special_from_(data)
+        if isinstance(data, Tensor): return self.special_from_(data)
         return self
 
     def __new__(cls, *args, **kwargs):
@@ -1338,7 +1337,7 @@ class Tensor(torch.Tensor):
         "FOR: stack"
         self = args[0]
         if isinstance(self, tuple): self = self[0]
-        dim = kwargs.get('dim', args[-1])
+        dim = kwargs.get('dim', args[-1] if isinstance(args[-1], INT) else 0)
 
         with torch._C.DisableTorchFunction():
             ret = super().__torch_function__(func, types, args, kwargs)
@@ -1407,7 +1406,7 @@ class Tensor(torch.Tensor):
                 collection = []
                 ret = Tensor.__torch_function_convert_collect__(ret, collection, cls)
                 for r in collection: r.special_from_()
-                return ret
+            return ret
 
         if torch_func_name is None: return Tensor.__torch_function_default_func__(func, types, args, kwargs)
         else: return eval(f"Tensor.{torch_func_name}")(func, types, args, kwargs)
@@ -1510,7 +1509,8 @@ def cat(*list_of_tensors, dim=None, **kwargs):
         else: dim = 0
     if len(list_of_tensors) == 1 and isinstance(list_of_tensors[0], (tuple, list)):
         list_of_tensors = list_of_tensors[0]
-    return torch.cat(list_of_tensors, dim, **kwargs)
+    self = [t for t in list_of_tensors if isinstance(t, Tensor)][0]
+    return torch.cat(list_of_tensors, dim, **kwargs).as_subclass(Tensor).special_from_(self)
 
 def stack(*list_of_tensors, dim=None, **kwargs):
     if dim is None:
@@ -1522,20 +1522,23 @@ def stack(*list_of_tensors, dim=None, **kwargs):
         else: dim = 0
     if len(list_of_tensors) == 1 and isinstance(list_of_tensors[0], (tuple, list)):
         list_of_tensors = list_of_tensors[0]
-    return torch.stack(list_of_tensors, dim, **kwargs)
+    self = [t for t in list_of_tensors if isinstance(t, Tensor)][0]
+    return torch.stack(list_of_tensors, dim, **kwargs).as_subclass(Tensor).set_special_(special=[x + 1 if x >= dim else x for x in self._special])
 
 @params
 def t(tensor: Array.Torch):
     if isinstance(tensor, Tensor): return tensor.T
-    else: return torch.t(tensor)
+    else: return torch.t(tensor).as_subclass(Tensor).special_from_(tensor)
 
 def unsqueeze(tensor, *args, **kwargs):
     if isinstance(tensor, Tensor): return tensor.unsqueeze(*args, **kwargs)
-    else: return torch.unsqueeze(tensor, *args, **kwargs)
+    else: return torch.unsqueeze(tensor, *args, **kwargs).as_subclass(Tensor).special_from_(tensor)
 
 def tensor(data, *, dtype=None, device=None, requires_grad=False, pin_memory=False):
     if device is None and _auto_device is True:
         device = Device
+    if isinstance(data, Tensor):
+        return data.clone().special_from_()
     if isinstance(data, torch.Tensor):
         return data.as_subclass(Tensor).special_from_()
     return torch.tensor(data, dtype=dtype, device=device, requires_grad=requires_grad, pin_memory=pin_memory).as_subclass(Tensor).special_from_()
